package javax.swing.text.html;

import javax.swing.text.View;
import java.awt.Container;
import java.awt.Component;
import javax.swing.text.JTextComponent;
import java.awt.Shape;
import java.awt.Graphics;
import javax.swing.text.Element;
import javax.swing.text.ComponentView;

class EditableView extends ComponentView
{
    private boolean isVisible;
    
    EditableView(Element elem) {
        super(elem);
    }
    
    @Override
    public float getMinimumSpan(int axis) {
        if (this.isVisible) {
            return super.getMinimumSpan(axis);
        }
        return 0.0f;
    }
    
    @Override
    public float getPreferredSpan(int axis) {
        if (this.isVisible) {
            return super.getPreferredSpan(axis);
        }
        return 0.0f;
    }
    
    @Override
    public float getMaximumSpan(int axis) {
        if (this.isVisible) {
            return super.getMaximumSpan(axis);
        }
        return 0.0f;
    }
    
    @Override
    public void paint(Graphics g, Shape a) {
        Component component = this.getComponent();
        Container container = this.getContainer();
        if (container instanceof JTextComponent && this.isVisible != ((JTextComponent)container).isEditable()) {
            this.isVisible = ((JTextComponent)container).isEditable();
            this.preferenceChanged(null, true, true);
            container.repaint();
        }
        if (this.isVisible) {
            super.paint(g, a);
        }
        else {
            this.setSize(0.0f, 0.0f);
        }
        if (component != null) {
            component.setFocusable(this.isVisible);
        }
    }
    
    @Override
    public void setParent(View parent) {
        if (parent != null) {
            Container container = parent.getContainer();
            if (container != null) {
                if ((container instanceof JTextComponent)) {
                    this.isVisible = ((JTextComponent)container).isEditable();
                }
                else {
                    this.isVisible = false;
                }
            }
        }
        super.setParent(parent);
    }
    
    @Override
    public boolean isVisible() {
        return this.isVisible;
    }
}
